# Django WikiWikiWeb

Django WikiWikiWeb is a Python + Django Wiki app. It is heavily inspired by [the original Wiki](https://wiki.c2.com/?) built by Ward Cunningham, whilst not quite being a [WikiClone](https://wiki.c2.com/?WikiWikiClones). It contains a few extra, modern features, integrates with the Django admin and auth systems, and will not be recreating the [controversial](https://news.ycombinator.com/item?id=8983158) newer JavaScript/single-page interface. 

## Installation

```pip install django-wikiwikiweb```

Complete instructions including initial configuration are here: 
https://django-wikiwikiweb.readthedocs.io/en/latest/installation.html

## Links

* Source code: https://github.com/simonharris/django-wikiwikiweb/
* Documentation: https://django-wikiwikiweb.readthedocs.io/
* Package on PyPI: https://pypi.org/project/django-wikiwikiweb/

